# Table of Contents

- [configuring-sap-cloud-alm-integration-for-managing-projects](<./configuring-sap-cloud-alm-integration-for-managing-projects.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SAP Cloud ALM Integration For Managing Projects](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects.md>)
  - [Introduction](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Introduction.md>)
  - [Setting Up an SAP Cloud ALM Instance](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Setting-Up-an-SAP-Cloud-ALM-Instance.md>)
  - [Enabling API Access to SAP Cloud ALM](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Enabling-API-Access-to-SAP-Cloud-ALM.md>)
  - [Validating the Cloud ALM Service Key](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Validating-the-Cloud-ALM-Service-Key.md>)
  - [Connecting SAP LeanIX to the SAP Cloud ALM API](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Connecting-SAP-LeanIX-to-the-SAP-Cloud-ALM-API.md>)
  - [Troubleshooting](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Troubleshooting.md>)
  - [Importing and Exporting Projects](<./Configuring-SAP-Cloud-ALM-Integration-For-Managing-Projects/Importing-and-Exporting-Projects.md>)
